@@ -44,7 +44,7 @@ class GithubApp:
             # GitHub App's identifier
             "iss": self.appid
         }
-        jwt.encode(payload, private_key, algorithm='RS256')
+        jwt.encode(payload, private_key, algorithm='RS256').decode("utf-8")
     def request(self, url, method='GET'):
         if method == 'GET':
             requestfunc = requests.get
@@ -54,7 +54,7 @@ class GithubApp:
 
         headers = {
             'Authorization': 'Bearer %s' % (apptoken,),
-            'Accept': 'application/vnd.github+json',
+            'Accept': 'application/vnd.github.machine-man-preview+json',
             'User-Agent': self.useragent
         }
 
@@ -105,7 +105,7 @@ class GithubAppInstall:
 
     def request(self, url):
         client = self.get_github3_client()
-        headers = {'Accept': 'application/vnd.github+json'}
+        headers = {'Accept': 'application/vnd.github.machine-man-preview+json'}
         res = client._get(url, headers=headers)
         res.raise_for_status()
         return res
